==> openshift-model-installer-6.7.2-sources.jar: io/fabric8/openshift/api/model/installer/alibabacloud/v1/MachinePoolBuilder.java <==
package io.fabric8.openshift.api.model.installer.alibabacloud.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class MachinePoolBuilder extends MachinePoolFluentImpl<MachinePoolBuilder> implements VisitableBuilder<MachinePool,MachinePoolBuilder>{
  public MachinePoolBuilder() {
    this(false);
  }
  public MachinePoolBuilder(Boolean validationEnabled) {
    this(new MachinePool(), validationEnabled);
  }
  public MachinePoolBuilder(MachinePoolFluent<?> fluent) {
    this(fluent, false);
  }
  public MachinePoolBuilder(MachinePoolFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new MachinePool(), validationEnabled);
  }
  public MachinePoolBuilder(MachinePoolFluent<?> fluent,MachinePool instance) {
    this(fluent, instance, false);
  }
  public MachinePoolBuilder(MachinePoolFluent<?> fluent,MachinePool instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withImageID(instance.getImageID());
      fluent.withInstanceType(instance.getInstanceType());
      fluent.withSystemDiskCategory(instance.getSystemDiskCategory());
      fluent.withSystemDiskSize(instance.getSystemDiskSize());
      fluent.withZones(instance.getZones());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public MachinePoolBuilder(MachinePool instance) {
    this(instance,false);
  }
  public MachinePoolBuilder(MachinePool instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withImageID(instance.getImageID());
      this.withInstanceType(instance.getInstanceType());
      this.withSystemDiskCategory(instance.getSystemDiskCategory());
      this.withSystemDiskSize(instance.getSystemDiskSize());
      this.withZones(instance.getZones());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  MachinePoolFluent<?> fluent;
  Boolean validationEnabled;
  public MachinePool build() {
    MachinePool buildable = new MachinePool(fluent.getImageID(),fluent.getInstanceType(),fluent.getSystemDiskCategory(),fluent.getSystemDiskSize(),fluent.getZones());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-installer-6.8.0-sources.jar: io/fabric8/openshift/api/model/installer/alibabacloud/v1/MachinePoolBuilder.java <==
package io.fabric8.openshift.api.model.installer.alibabacloud.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class MachinePoolBuilder extends MachinePoolFluent<MachinePoolBuilder> implements VisitableBuilder<MachinePool,MachinePoolBuilder>{
  public MachinePoolBuilder() {
    this(false);
  }
  public MachinePoolBuilder(Boolean validationEnabled) {
    this(new MachinePool(), validationEnabled);
  }
  public MachinePoolBuilder(MachinePoolFluent<?> fluent) {
    this(fluent, false);
  }
  public MachinePoolBuilder(MachinePoolFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new MachinePool(), validationEnabled);
  }
  public MachinePoolBuilder(MachinePoolFluent<?> fluent,MachinePool instance) {
    this(fluent, instance, false);
  }
  public MachinePoolBuilder(MachinePoolFluent<?> fluent,MachinePool instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new MachinePool());

    if (instance != null) {
      fluent.withImageID(instance.getImageID());
      fluent.withInstanceType(instance.getInstanceType());
      fluent.withSystemDiskCategory(instance.getSystemDiskCategory());
      fluent.withSystemDiskSize(instance.getSystemDiskSize());
      fluent.withZones(instance.getZones());
      fluent.withImageID(instance.getImageID());
      fluent.withInstanceType(instance.getInstanceType());
      fluent.withSystemDiskCategory(instance.getSystemDiskCategory());
      fluent.withSystemDiskSize(instance.getSystemDiskSize());
      fluent.withZones(instance.getZones());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public MachinePoolBuilder(MachinePool instance) {
    this(instance,false);
  }
  public MachinePoolBuilder(MachinePool instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new MachinePool());

    if (instance != null) {
      this.withImageID(instance.getImageID());
      this.withInstanceType(instance.getInstanceType());
      this.withSystemDiskCategory(instance.getSystemDiskCategory());
      this.withSystemDiskSize(instance.getSystemDiskSize());
      this.withZones(instance.getZones());
      this.withImageID(instance.getImageID());
      this.withInstanceType(instance.getInstanceType());
      this.withSystemDiskCategory(instance.getSystemDiskCategory());
      this.withSystemDiskSize(instance.getSystemDiskSize());
      this.withZones(instance.getZones());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  MachinePoolFluent<?> fluent;
  Boolean validationEnabled;
  public MachinePool build() {
    MachinePool buildable = new MachinePool(fluent.getImageID(),fluent.getInstanceType(),fluent.getSystemDiskCategory(),fluent.getSystemDiskSize(),fluent.getZones());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
